/*
 * (c) 2009 Lehrstuhl fuer Softwaretechnik und Programmiersprachen, 
 * Heinrich Heine Universitaet Duesseldorf
 * This software is licenced under EPL 1.0 (http://www.eclipse.org/org/documents/epl-v10.html) 
 * */

package de.hhu.stups.sablecc.patch;

public class PositionedNode {
  private SourcePosition startPos;
  private SourcePosition endPos;

  public PositionedNode(final SourcePosition startPos, final SourcePosition endPos) {
    this.startPos = startPos;
    this.endPos = endPos;
  }

  public PositionedNode() {
    this(null, null);
  }

  @Deprecated
  public PositionedNode(final PositionedNode node) {
    this(node.startPos, node.endPos);
  }

  /**
   * Copies the {@link SourcePosition}s from the given node to this node.
   * This is an internal helper method for use in {@link Object#clone()} implementations.
   * 
   * @param node the node from which to copy the source positions
   */
  protected final void initSourcePositionsFrom(PositionedNode node) {
    // Intentionally do not use the accessors (getStartPos, getEndPos) here
    // so that cloning a Token does not trigger lazy creation of SourcePosition objects.
    this.startPos = node.startPos;
    this.endPos = node.endPos;
  }

  public SourcePosition getStartPos() {
    return startPos;
  }

  public SourcePosition getEndPos() {
    return endPos;
  }

  public void setStartPos(final SourcePosition startPos) {
    this.startPos = startPos;
  }

  public void setEndPos(final SourcePosition endPos) {
    this.endPos = endPos;
  }
}
